@@ -1,4 +1,4 @@
-#!D:\bld\digital_rf_1591044018559\_h_env\python.exe
+#!D:\bld\digital_rf_1591117694997\_h_env\python.exe
 # ----------------------------------------------------------------------------
 # Copyright (c) 2017 Massachusetts Institute of Technology (MIT)
 # All rights reserved.
@@ -602,12 +602,12 @@ def rti_process(
         block_size = integration * modulus
         block_toffset = toffset
 
-        rti_bins = len(data) / block_size
+        rti_bins = len(data) // block_size
 
         RTIdata = np.zeros([modulus, rti_bins], np.complex64)
         RTItimes = np.zeros([rti_bins])
 
-        while block < len(data) / block_size:
+        while block < rti_bins:
 
             vblock = data[block * block_size : block * block_size + modulus]
             pblock = vblock * np.conjugate(vblock)
@@ -740,12 +740,12 @@ def sti_process(
         block_size = integration * modulus
         block_toffset = toffset
 
-        sti_bins = len(data) / block_size
+        sti_bins = len(data) // block_size
 
         STIdata = np.zeros([bins, sti_bins], np.complex64)
         STItimes = np.zeros([sti_bins])
 
-        while block < len(data) / block_size:
+        while block < sti_bins:
 
             vblock = data[block * block_size : block * block_size + modulus]
             pblock, freq = matplotlib.mlab.psd(
@@ -996,11 +996,10 @@ def apply_msl_filter(data, msl_code_length, msl_baud_length):
 
     print(("msl filter data with code ", msl_code_length))
     code = code_table[msl_code_length]
-    # note that the codes are time reversed as defined compared to what we send
+    block = msl_baud_length
     x_msl = np.zeros(msl_baud_length * len(code), dtype=np.complex64)
     idx = 0
     for c in code:
-        block = len(x_msl) / len(code)
         if c == 1:
             x_msl[idx * block : idx * block + block] = (
                 np.ones(block, dtype=np.float64) + 0j
@@ -1011,7 +1010,7 @@ def apply_msl_filter(data, msl_code_length, msl_baud_length):
             )
         idx += 1
 
-    dc = np.convolve(d, x_msl, "same")
+    dc = np.correlate(data, x_msl, "full")[(len(x_msl) - 1):(len(data) + len(x_msl) - 1)]
 
     return dc
 
@@ -1190,7 +1189,7 @@ if __name__ == "__main__":
                 atime = int(np.uint64(atime * sfreq_ld))
 
             sstart = atime + int(toffset)
-            dlen = stop_sample - start_sample + 1
+            dlen = stop_sample - start_sample
 
             print(sstart, dlen)
 
